@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,12 +26,7 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtkwindow.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtktable.h>
+#include <gtk/gtk.h>
 
 #include "alertpanel.h"
 #include "mgutils.h"
@@ -70,7 +65,7 @@ typedef enum {
 #define EDITPERSON_WIDTH      520
 #define EDITPERSON_HEIGHT     320
 
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 # define EMAIL_N_COLS          3
 # define EMAIL_COL_WIDTH_EMAIL 180
 # define EMAIL_COL_WIDTH_ALIAS 80
@@ -80,7 +75,7 @@ typedef enum {
 # define EMAIL_COL_WIDTH_ALIAS 130
 #endif
 
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 # define ATTRIB_N_COLS          2
 # define ATTRIB_COL_WIDTH_NAME  240
 # define ATTRIB_COL_WIDTH_VALUE 0
@@ -102,7 +97,7 @@ static gchar* edit_person_get_common_name_from_widgets(void)
 {
 	gchar *cn = NULL; /* cn must be freed by caller */
 
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 	{
 		cn = gtk_editable_get_chars( GTK_EDITABLE(personeditdlg.entry_name), 0, -1 );
 		if ( cn == NULL || *cn == '\0' ) {
@@ -157,7 +152,7 @@ static void edit_person_ok(GtkWidget *widget, gboolean *cancelled) {
 		gint val;
 
 		val = alertpanel( _("Add New Person"),
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 				_("Adding a new person requires at least one of the\n"
 				  "following values to be set:\n"
 				  " - Display Name\n"
@@ -220,7 +215,7 @@ static void edit_person_set_widgets_title( gchar *text )
 {
 	gchar *label = NULL;
 
-	g_return_if_fail( text != NULL );
+	cm_return_if_fail( text != NULL );
 
 	gtk_label_set_text(GTK_LABEL(personeditdlg.title), "");
 	label = g_markup_printf_escaped("<b>%s</b>", text);
@@ -280,7 +275,7 @@ static void edit_person_email_clear( gpointer data ) {
 
 static void edit_person_attrib_clear( gpointer data ) {
 	if (!personeditdlg.ldap) {
-		gtk_entry_set_text( GTK_ENTRY(GTK_BIN(personeditdlg.entry_atname)->child), "" );
+		gtk_entry_set_text( GTK_ENTRY(gtk_bin_get_child(GTK_BIN((personeditdlg.entry_atname)))), "" );
 		gtk_entry_set_text( GTK_ENTRY(personeditdlg.entry_atvalue), "" );
 	}
 }
@@ -297,25 +292,25 @@ static void edit_person_switch_page( GtkNotebook *notebook, GtkNotebookPage *pag
 */
 static void edit_person_load_email( ItemPerson *person ) {
 	GList *node = person->listEMail;
-	GtkCList *clist = GTK_CLIST(personeditdlg.clist_email);
+	GtkCMCList *clist = GTK_CMCLIST(personeditdlg.clist_email);
 	gchar *text[ EMAIL_N_COLS ];
 	while( node ) {
 		ItemEMail *emorig = ( ItemEMail * ) node->data;
 		ItemEMail *email = addritem_copyfull_item_email( emorig );
 		gint row;
 		text[ EMAIL_COL_EMAIL   ] = email->address;
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 		text[ EMAIL_COL_ALIAS   ] = email->obj.name;
 		text[ EMAIL_COL_REMARKS ] = email->remarks;
 #endif
-		row = gtk_clist_append( clist, text );
-		gtk_clist_set_row_data( clist, row, email );
+		row = gtk_cmclist_append( clist, text );
+		gtk_cmclist_set_row_data( clist, row, email );
 		node = g_list_next( node );
 	}
 }
 
-static void edit_person_email_list_selected( GtkCList *clist, gint row, gint column, GdkEvent *event, gpointer data ) {
-	ItemEMail *email = gtk_clist_get_row_data( clist, row );
+static void edit_person_email_list_selected( GtkCMCList *clist, gint row, gint column, GdkEvent *event, gpointer data ) {
+	ItemEMail *email = gtk_cmclist_get_row_data( clist, row );
 	if( email ) {
 		if( email->address )
 			gtk_entry_set_text( GTK_ENTRY(personeditdlg.entry_email), email->address );
@@ -326,7 +321,7 @@ static void edit_person_email_list_selected( GtkCList *clist, gint row, gint col
 		if (!personeditdlg.read_only) {
 			gtk_widget_set_sensitive(personeditdlg.email_del, TRUE);
 			gtk_widget_set_sensitive(personeditdlg.email_up, row > 0);
-			gtk_widget_set_sensitive(personeditdlg.email_down, gtk_clist_get_row_data(clist, row + 1) != NULL);
+			gtk_widget_set_sensitive(personeditdlg.email_down, gtk_cmclist_get_row_data(clist, row + 1) != NULL);
 		}
 	} else {
 		gtk_widget_set_sensitive(personeditdlg.email_del, FALSE);
@@ -338,15 +333,15 @@ static void edit_person_email_list_selected( GtkCList *clist, gint row, gint col
 }
 
 static void edit_person_email_move( gint dir ) {
-	GtkCList *clist = GTK_CLIST(personeditdlg.clist_email);
+	GtkCMCList *clist = GTK_CMCLIST(personeditdlg.clist_email);
 	gint row = personeditdlg.rowIndEMail + dir;
-	ItemEMail *email = gtk_clist_get_row_data( clist, row );
+	ItemEMail *email = gtk_cmclist_get_row_data( clist, row );
 	if( email ) {
-		gtk_clist_row_move( clist, personeditdlg.rowIndEMail, row );
+		gtk_cmclist_row_move( clist, personeditdlg.rowIndEMail, row );
 		personeditdlg.rowIndEMail = row;
 		if (!personeditdlg.read_only) {
 			gtk_widget_set_sensitive(personeditdlg.email_up, row > 0);
-			gtk_widget_set_sensitive(personeditdlg.email_down, gtk_clist_get_row_data(clist, row + 1) != NULL);
+			gtk_widget_set_sensitive(personeditdlg.email_down, gtk_cmclist_get_row_data(clist, row + 1) != NULL);
 		}
 	} else {
 		gtk_widget_set_sensitive(personeditdlg.email_up, FALSE);
@@ -365,26 +360,26 @@ static void edit_person_email_move_down( gpointer data ) {
 }
 
 static void edit_person_email_delete( gpointer data ) {
-	GtkCList *clist = GTK_CLIST(personeditdlg.clist_email);
+	GtkCMCList *clist = GTK_CMCLIST(personeditdlg.clist_email);
 	gint row = personeditdlg.rowIndEMail;
-	ItemEMail *email = gtk_clist_get_row_data( clist, row );
+	ItemEMail *email = gtk_cmclist_get_row_data( clist, row );
 	edit_person_email_clear( NULL );
 	if( email ) {
 		/* Remove list entry */
-		gtk_clist_remove( clist, row );
+		gtk_cmclist_remove( clist, row );
 		addritem_free_item_email( email );
 		email = NULL;
 	}
 
 	/* Position hilite bar */
-	email = gtk_clist_get_row_data( clist, row );
+	email = gtk_cmclist_get_row_data( clist, row );
 	if( ! email ) {
 		personeditdlg.rowIndEMail = -1 + row;
 	}
 	if (!personeditdlg.read_only) {
-		gtk_widget_set_sensitive(personeditdlg.email_del, gtk_clist_get_row_data(clist, 0) != NULL);
-		gtk_widget_set_sensitive(personeditdlg.email_up, gtk_clist_get_row_data(clist, personeditdlg.rowIndEMail + 1) != NULL);
-		gtk_widget_set_sensitive(personeditdlg.email_down, gtk_clist_get_row_data(clist, personeditdlg.rowIndEMail - 1) != NULL);
+		gtk_widget_set_sensitive(personeditdlg.email_del, gtk_cmclist_get_row_data(clist, 0) != NULL);
+		gtk_widget_set_sensitive(personeditdlg.email_up, gtk_cmclist_get_row_data(clist, personeditdlg.rowIndEMail + 1) != NULL);
+		gtk_widget_set_sensitive(personeditdlg.email_down, gtk_cmclist_get_row_data(clist, personeditdlg.rowIndEMail - 1) != NULL);
 	}
 	edit_person_status_show( NULL );
 }
@@ -423,38 +418,38 @@ static ItemEMail *edit_person_email_edit( gboolean *error, ItemEMail *email ) {
 
 static void edit_person_email_modify( gpointer data ) {
 	gboolean errFlg = FALSE;
-	GtkCList *clist = GTK_CLIST(personeditdlg.clist_email);
+	GtkCMCList *clist = GTK_CMCLIST(personeditdlg.clist_email);
 	gint row = personeditdlg.rowIndEMail;
-	ItemEMail *email = gtk_clist_get_row_data( clist, row );
+	ItemEMail *email = gtk_cmclist_get_row_data( clist, row );
 	if( email ) {
 		edit_person_email_edit( &errFlg, email );
 		if( ! errFlg ) {
-			gtk_clist_set_text( clist, row, EMAIL_COL_EMAIL, email->address );
-			gtk_clist_set_text( clist, row, EMAIL_COL_ALIAS, email->obj.name );
-			gtk_clist_set_text( clist, row, EMAIL_COL_REMARKS, email->remarks );
+			gtk_cmclist_set_text( clist, row, EMAIL_COL_EMAIL, email->address );
+			gtk_cmclist_set_text( clist, row, EMAIL_COL_ALIAS, email->obj.name );
+			gtk_cmclist_set_text( clist, row, EMAIL_COL_REMARKS, email->remarks );
 			edit_person_email_clear( NULL );
 		}
 	}
 }
 
 static void edit_person_email_add( gpointer data ) {
-	GtkCList *clist = GTK_CLIST(personeditdlg.clist_email);
+	GtkCMCList *clist = GTK_CMCLIST(personeditdlg.clist_email);
 	gboolean errFlg = FALSE;
 	ItemEMail *email = NULL;
 	gint row = personeditdlg.rowIndEMail;
-	if( gtk_clist_get_row_data( clist, row ) == NULL ) row = 0;
+	if( gtk_cmclist_get_row_data( clist, row ) == NULL ) row = 0;
 
 	email = edit_person_email_edit( &errFlg, NULL );
 	if( ! errFlg ) {
 		gchar *text[ EMAIL_N_COLS ];
 		text[ EMAIL_COL_EMAIL   ] = email->address;
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 		text[ EMAIL_COL_ALIAS   ] = email->obj.name;
 		text[ EMAIL_COL_REMARKS ] = email->remarks;
 #endif
-		row = gtk_clist_insert( clist, 1 + row, text );
-		gtk_clist_set_row_data( clist, row, email );
-		gtk_clist_select_row( clist, row, 0 );
+		row = gtk_cmclist_insert( clist, 1 + row, text );
+		gtk_cmclist_set_row_data( clist, row, email );
+		gtk_cmclist_select_row( clist, row, 0 );
 		edit_person_email_clear( NULL );
 	}
 }
@@ -464,10 +459,10 @@ static void edit_person_email_add( gpointer data ) {
 * address index widget.
 */
 static gint edit_person_attrib_compare_func(
-	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2 )
+	GtkCMCList *clist, gconstpointer ptr1, gconstpointer ptr2 )
 {
-	GtkCell *cell1 = ((GtkCListRow *)ptr1)->cell;
-	GtkCell *cell2 = ((GtkCListRow *)ptr2)->cell;
+	GtkCMCell *cell1 = ((GtkCMCListRow *)ptr1)->cell;
+	GtkCMCell *cell2 = ((GtkCMCListRow *)ptr2)->cell;
 	gchar *name1 = NULL, *name2 = NULL;
 
 	if( cell1 ) name1 = cell1->u.text;
@@ -479,12 +474,12 @@ static gint edit_person_attrib_compare_func(
 
 static gboolean list_find_attribute(const gchar *attr)
 {
-	GtkCList *clist = GTK_CLIST(personeditdlg.clist_attrib);
+	GtkCMCList *clist = GTK_CMCLIST(personeditdlg.clist_attrib);
 	UserAttribute *attrib;
 	gint row = 0;
-	while( (attrib = gtk_clist_get_row_data( clist, row )) ) {
+	while( (attrib = gtk_cmclist_get_row_data( clist, row )) ) {
 		if (!g_ascii_strcasecmp(attrib->name, attr)) {
-			gtk_clist_select_row(clist, row, 0);
+			gtk_cmclist_select_row(clist, row, 0);
 			return TRUE;
 		}
 		row++;
@@ -494,12 +489,12 @@ static gboolean list_find_attribute(const gchar *attr)
 
 static gboolean list_find_email(const gchar *addr)
 {
-	GtkCList *clist = GTK_CLIST(personeditdlg.clist_email);
+	GtkCMCList *clist = GTK_CMCLIST(personeditdlg.clist_email);
 	ItemEMail *email;
 	gint row = 0;
-	while( (email = gtk_clist_get_row_data( clist, row )) ) {
+	while( (email = gtk_cmclist_get_row_data( clist, row )) ) {
 		if (!g_ascii_strcasecmp(email->address, addr)) {
-			gtk_clist_select_row(clist, row, 0);
+			gtk_cmclist_select_row(clist, row, 0);
 			return TRUE;
 		}
 		row++;
@@ -512,7 +507,7 @@ static gboolean list_find_email(const gchar *addr)
 */
 static void edit_person_load_attrib( ItemPerson *person ) {
 	GList *node = person->listAttrib;
-	GtkCList *clist = GTK_CLIST(personeditdlg.clist_attrib);
+	GtkCMCList *clist = GTK_CMCLIST(personeditdlg.clist_attrib);
 	gchar *text[ ATTRIB_N_COLS ];
 	while( node ) {
 		UserAttribute *atorig = ( UserAttribute * ) node->data;
@@ -522,16 +517,16 @@ static void edit_person_load_attrib( ItemPerson *person ) {
 		text[ ATTRIB_COL_NAME  ] = attrib->name;
 		text[ ATTRIB_COL_VALUE ] = attrib->value;
 
-		row = gtk_clist_append( clist, text );
-		gtk_clist_set_row_data( clist, row, attrib );
+		row = gtk_cmclist_append( clist, text );
+		gtk_cmclist_set_row_data( clist, row, attrib );
 		node = g_list_next( node );
 	}
 }
 
-static void edit_person_attrib_list_selected( GtkCList *clist, gint row, gint column, GdkEvent *event, gpointer data ) {
-	UserAttribute *attrib = gtk_clist_get_row_data( clist, row );
+static void edit_person_attrib_list_selected( GtkCMCList *clist, gint row, gint column, GdkEvent *event, gpointer data ) {
+	UserAttribute *attrib = gtk_cmclist_get_row_data( clist, row );
 	if( attrib && !personeditdlg.read_only && !personeditdlg.ldap ) {
-		gtk_entry_set_text( GTK_ENTRY(GTK_BIN(personeditdlg.entry_atname)->child ), attrib->name );
+		gtk_entry_set_text( GTK_ENTRY(gtk_bin_get_child(GTK_BIN((personeditdlg.entry_atname))) ), attrib->name );
 		gtk_entry_set_text( GTK_ENTRY(personeditdlg.entry_atvalue), attrib->value );
 		gtk_widget_set_sensitive(personeditdlg.attrib_del, TRUE);
 	} else {
@@ -542,25 +537,25 @@ static void edit_person_attrib_list_selected( GtkCList *clist, gint row, gint co
 }
 
 static void edit_person_attrib_delete( gpointer data ) {
-	GtkCList *clist = GTK_CLIST(personeditdlg.clist_attrib);
+	GtkCMCList *clist = GTK_CMCLIST(personeditdlg.clist_attrib);
 	gint row = personeditdlg.rowIndAttrib;
-	UserAttribute *attrib = gtk_clist_get_row_data( clist, row );
+	UserAttribute *attrib = gtk_cmclist_get_row_data( clist, row );
 	edit_person_attrib_clear( NULL );
 	if( attrib ) {
 		/* Remove list entry */
-		gtk_clist_remove( clist, row );
+		gtk_cmclist_remove( clist, row );
 		addritem_free_attribute( attrib );
 		attrib = NULL;
 	}
 
 	/* Position hilite bar */
-	attrib = gtk_clist_get_row_data( clist, row );
+	attrib = gtk_cmclist_get_row_data( clist, row );
 	if( ! attrib ) {
 		personeditdlg.rowIndAttrib = -1 + row;
 	} 
 	
 	if (!personeditdlg.read_only && !personeditdlg.ldap)
-		gtk_widget_set_sensitive(personeditdlg.attrib_del, gtk_clist_get_row_data(clist, 0) != NULL);
+		gtk_widget_set_sensitive(personeditdlg.attrib_del, gtk_cmclist_get_row_data(clist, 0) != NULL);
 	
 	edit_person_status_show( NULL );
 }
@@ -570,7 +565,7 @@ static UserAttribute *edit_person_attrib_edit( gboolean *error, UserAttribute *a
 	gchar *sName, *sValue, *sName_, *sValue_;
 
 	*error = TRUE;
-	sName_ = gtk_editable_get_chars( GTK_EDITABLE(GTK_BIN(personeditdlg.entry_atname)->child), 0, -1 );
+	sName_ = gtk_editable_get_chars( GTK_EDITABLE(gtk_bin_get_child(GTK_BIN((personeditdlg.entry_atname)))), 0, -1 );
 	sValue_ = gtk_editable_get_chars( GTK_EDITABLE(personeditdlg.entry_atvalue), 0, -1 );
 	sName = mgu_email_check_empty( sName_ );
 	sValue = mgu_email_check_empty( sValue_ );
@@ -598,25 +593,25 @@ static UserAttribute *edit_person_attrib_edit( gboolean *error, UserAttribute *a
 
 static void edit_person_attrib_modify( gpointer data ) {
 	gboolean errFlg = FALSE;
-	GtkCList *clist = GTK_CLIST(personeditdlg.clist_attrib);
+	GtkCMCList *clist = GTK_CMCLIST(personeditdlg.clist_attrib);
 	gint row = personeditdlg.rowIndAttrib;
-	UserAttribute *attrib = gtk_clist_get_row_data( clist, row );
+	UserAttribute *attrib = gtk_cmclist_get_row_data( clist, row );
 	if( attrib ) {
 		edit_person_attrib_edit( &errFlg, attrib );
 		if( ! errFlg ) {
-			gtk_clist_set_text( clist, row, ATTRIB_COL_NAME, attrib->name );
-			gtk_clist_set_text( clist, row, ATTRIB_COL_VALUE, attrib->value );
+			gtk_cmclist_set_text( clist, row, ATTRIB_COL_NAME, attrib->name );
+			gtk_cmclist_set_text( clist, row, ATTRIB_COL_VALUE, attrib->value );
 			edit_person_attrib_clear( NULL );
 		}
 	}
 }
 
 static void edit_person_attrib_add( gpointer data ) {
-	GtkCList *clist = GTK_CLIST(personeditdlg.clist_attrib);
+	GtkCMCList *clist = GTK_CMCLIST(personeditdlg.clist_attrib);
 	gboolean errFlg = FALSE;
 	UserAttribute *attrib = NULL;
 	gint row = personeditdlg.rowIndAttrib;
-	if( gtk_clist_get_row_data( clist, row ) == NULL ) row = 0;
+	if( gtk_cmclist_get_row_data( clist, row ) == NULL ) row = 0;
 
 	attrib = edit_person_attrib_edit( &errFlg, NULL );
 	if( ! errFlg ) {
@@ -624,9 +619,9 @@ static void edit_person_attrib_add( gpointer data ) {
 		text[ ATTRIB_COL_NAME  ] = attrib->name;
 		text[ ATTRIB_COL_VALUE ] = attrib->value;
 
-		row = gtk_clist_insert( clist, 1 + row, text );
-		gtk_clist_set_row_data( clist, row, attrib );
-		gtk_clist_select_row( clist, row, 0 );
+		row = gtk_cmclist_insert( clist, 1 + row, text );
+		gtk_cmclist_set_row_data( clist, row, attrib );
+		gtk_cmclist_select_row( clist, row, 0 );
 		edit_person_attrib_clear( NULL );
 	}
 }
@@ -637,7 +632,7 @@ static void edit_person_attrib_add( gpointer data ) {
 static void edit_person_size_allocate_cb(GtkWidget *widget,
 					 GtkAllocation *allocation)
 {
-	g_return_if_fail(allocation != NULL);
+	cm_return_if_fail(allocation != NULL);
 
 	prefs_common.addressbookeditpersonwin_width = allocation->width;
 	prefs_common.addressbookeditpersonwin_height = allocation->height;
@@ -815,8 +810,7 @@ static void addressbook_edit_person_set_picture(void)
 			return;
 		}
 		personeditdlg.picture_set = TRUE;
-		menu_set_sensitive(personeditdlg.editaddr_popupfactory,
-				"/Unset picture", personeditdlg.picture_set);
+		cm_menu_set_sensitive("EditAddressPopup/UnsetPicture", personeditdlg.picture_set);
 		g_free(filename);
 		gtk_image_set_from_pixbuf(GTK_IMAGE(personeditdlg.image), pixbuf);
 		g_object_unref(pixbuf);
@@ -829,25 +823,26 @@ static void addressbook_edit_person_clear_picture(void)
 
 	stock_pixbuf_gdk(NULL, STOCK_PIXMAP_ANONYMOUS, &pixbuf);
 	personeditdlg.picture_set = FALSE;
-	menu_set_sensitive(personeditdlg.editaddr_popupfactory,
-			"/Unset picture", personeditdlg.picture_set);
+	cm_menu_set_sensitive("EditAddressPopup/UnsetPicture", personeditdlg.picture_set);
 	gtk_image_set_from_pixbuf(GTK_IMAGE(personeditdlg.image), pixbuf);
 }
 
-static void addressbook_edit_person_set_picture_menu_cb (void *obj, guint action, void *data)
+static void addressbook_edit_person_set_picture_menu_cb (GtkAction *action, gpointer data)
 {
 	addressbook_edit_person_set_picture();
 }
 
-static void addressbook_edit_person_unset_picture_menu_cb (void *obj, guint action, void *data)
+static void addressbook_edit_person_unset_picture_menu_cb (GtkAction *action, gpointer data)
 {
 	addressbook_edit_person_clear_picture();
 }
 
-static GtkItemFactoryEntry editaddr_popup_entries[] =
+static GtkWidget *editaddr_popup_menu = NULL;
+static GtkActionEntry editaddr_popup_entries[] =
 {
-	{N_("/_Set picture"),		NULL, addressbook_edit_person_set_picture_menu_cb, 0, NULL, NULL},
-	{N_("/_Unset picture"),		NULL, addressbook_edit_person_unset_picture_menu_cb, 0, NULL, NULL},
+	{"EditAddressPopup",			NULL, "EditAddressPopup" },
+	{"EditAddressPopup/SetPicture",		NULL, N_("_Set picture"), NULL, NULL, G_CALLBACK(addressbook_edit_person_set_picture_menu_cb) },
+	{"EditAddressPopup/UnsetPicture",	NULL, N_("_Unset picture"), NULL, NULL, G_CALLBACK(addressbook_edit_person_unset_picture_menu_cb) },
 };
 
 static void addressbook_edit_person_set_picture_cb(GtkWidget *widget, 
@@ -856,7 +851,7 @@ static void addressbook_edit_person_set_picture_cb(GtkWidget *widget,
 	if (event->button == 1) {
 		addressbook_edit_person_set_picture();
 	} else {
-		gtk_menu_popup(GTK_MENU(personeditdlg.editaddr_popupmenu), 
+		gtk_menu_popup(GTK_MENU(editaddr_popup_menu), 
 			       NULL, NULL, NULL, NULL, 
 			       event->button, event->time);
 	}
@@ -887,19 +882,23 @@ static void addressbook_edit_person_page_basic( gint pageNum, gchar *pageLbl ) {
 	GtkWidget *entry_nn;
 	const gchar *locale;
 	gint top = 0;
-	gint n_entries;
+	GtkActionGroup *action_group;
+
 	vbox = gtk_vbox_new( FALSE, 20 );
 	hbox = gtk_hbox_new( FALSE, 8 );
 
 	gtk_widget_show( vbox );	
 
-	/* set up picture context menu before we call addressbook_edit_person_clear_picture() */	
-	n_entries = sizeof(editaddr_popup_entries) /
-		sizeof(editaddr_popup_entries[0]);
-	personeditdlg.editaddr_popupmenu = menu_create_items(editaddr_popup_entries, n_entries,
-				      "<EditAddrPopupMenu>", &personeditdlg.editaddr_popupfactory,
-				      NULL);
+	if (!editaddr_popup_menu) {
+		action_group = cm_menu_create_action_group("EditAddressPopup", editaddr_popup_entries,
+			G_N_ELEMENTS(editaddr_popup_entries), (gpointer)NULL);
+		MENUITEM_ADDUI("/Menus", "EditAddressPopup", "EditAddressPopup", GTK_UI_MANAGER_MENU)
+		MENUITEM_ADDUI("/Menus/EditAddressPopup", "SetPicture", "EditAddressPopup/SetPicture", GTK_UI_MANAGER_MENUITEM)
+		MENUITEM_ADDUI("/Menus/EditAddressPopup", "UnsetPicture", "EditAddressPopup/UnsetPicture", GTK_UI_MANAGER_MENUITEM)
 
+		editaddr_popup_menu = gtk_menu_item_get_submenu(GTK_MENU_ITEM(
+			gtk_ui_manager_get_widget(gtkut_ui_manager(), "/Menus/EditAddressPopup")) );
+	}
 	/* User's picture */
 	ebox_picture = gtk_event_box_new();
 	frame_picture = gtk_frame_new(_("Photo"));
@@ -955,7 +954,7 @@ static void addressbook_edit_person_page_basic( gint pageNum, gchar *pageLbl ) {
 	entry = gtk_entry_new(); \
 }
 
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 	ATTACH_ROW(_("Display Name"), entry_name);
 #else
 	ATTACH_HIDDEN_ROW(_("Display Name"), entry_name);
@@ -971,7 +970,7 @@ static void addressbook_edit_person_page_basic( gint pageNum, gchar *pageLbl ) {
 		ATTACH_ROW(_("First Name"), entry_fn);
 		ATTACH_ROW(_("Last Name"), entry_ln);
 	}
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 	ATTACH_ROW(_("Nickname"), entry_nn);
 #else
 	ATTACH_HIDDEN_ROW(_("Nickname"), entry_nn);
@@ -996,7 +995,7 @@ static gboolean email_adding = FALSE, email_saving = FALSE;
 
 static void edit_person_entry_email_changed (GtkWidget *entry, gpointer data)
 {
-	gboolean non_empty = gtk_clist_get_row_data(GTK_CLIST(personeditdlg.clist_email), 0) != NULL;
+	gboolean non_empty = gtk_cmclist_get_row_data(GTK_CMCLIST(personeditdlg.clist_email), 0) != NULL;
 
 	if (personeditdlg.read_only)
 		return;
@@ -1057,7 +1056,7 @@ static void addressbook_edit_person_page_email( gint pageNum, gchar *pageLbl ) {
 	gint i;
 
 	titles[ EMAIL_COL_EMAIL   ] = _("Email Address");
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 	titles[ EMAIL_COL_ALIAS   ] = _("Alias");
 	titles[ EMAIL_COL_REMARKS ] = _("Remarks");
 #endif
@@ -1086,26 +1085,26 @@ static void addressbook_edit_person_page_email( gint pageNum, gchar *pageLbl ) {
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
 
-	clist = gtk_clist_new_with_titles( EMAIL_N_COLS, titles );
+	clist = gtk_cmclist_new_with_titles( EMAIL_N_COLS, titles );
 
 	gtk_container_add( GTK_CONTAINER(clist_swin), clist );
-	gtk_clist_set_selection_mode( GTK_CLIST(clist), GTK_SELECTION_BROWSE );
-	gtk_clist_set_column_width( GTK_CLIST(clist), EMAIL_COL_EMAIL, EMAIL_COL_WIDTH_EMAIL );
-	gtk_clist_set_column_width( GTK_CLIST(clist), EMAIL_COL_ALIAS, EMAIL_COL_WIDTH_ALIAS );
+	gtk_cmclist_set_selection_mode( GTK_CMCLIST(clist), GTK_SELECTION_BROWSE );
+	gtk_cmclist_set_column_width( GTK_CMCLIST(clist), EMAIL_COL_EMAIL, EMAIL_COL_WIDTH_EMAIL );
+	gtk_cmclist_set_column_width( GTK_CMCLIST(clist), EMAIL_COL_ALIAS, EMAIL_COL_WIDTH_ALIAS );
 
 	for( i = 0; i < EMAIL_N_COLS; i++ )
-		GTK_WIDGET_UNSET_FLAGS(GTK_CLIST(clist)->column[i].button, GTK_CAN_FOCUS);
+		GTK_WIDGET_UNSET_FLAGS(GTK_CMCLIST(clist)->column[i].button, GTK_CAN_FOCUS);
 
 	/* Data entry area */
 	table = gtk_table_new( 4, 2, FALSE);
 
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 	gtk_container_add( GTK_CONTAINER(vboxl), clist_swin );
 	gtk_box_pack_start(GTK_BOX(vboxl), table, FALSE, FALSE, 0);
 #else
 	gtk_box_pack_start(GTK_BOX(vboxl), table, FALSE, FALSE, 0);
 	gtk_container_add( GTK_CONTAINER(vboxl), clist_swin );
-	gtk_clist_column_titles_hide(GTK_CLIST(clist));
+	gtk_cmclist_column_titles_hide(GTK_CMCLIST(clist));
 #endif
 	gtk_container_set_border_width( GTK_CONTAINER(table), 4 );
 	gtk_table_set_row_spacings(GTK_TABLE(table), 4);
@@ -1123,7 +1122,7 @@ static void addressbook_edit_person_page_email( gint pageNum, gchar *pageLbl ) {
 
 	gtk_table_attach(GTK_TABLE(table), entry_email, 1, 2, top, (top + 1), GTK_EXPAND|GTK_SHRINK|GTK_FILL, 0, 0, 0);
 
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 	/* Next row */
 	++top;
 	label = gtk_label_new(_("Alias"));
@@ -1159,7 +1158,7 @@ static void addressbook_edit_person_page_email( gint pageNum, gchar *pageLbl ) {
 	buttonAdd = gtk_button_new_from_stock(GTK_STOCK_ADD);
 	
 
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 	gtk_container_add( GTK_CONTAINER(vbuttonbox), buttonUp );
 
 	gtk_container_add( GTK_CONTAINER(vbuttonbox), buttonDown );
@@ -1209,13 +1208,13 @@ static gboolean attrib_adding = FALSE, attrib_saving = FALSE;
 
 static void edit_person_entry_att_changed (GtkWidget *entry, gpointer data)
 {
-	gboolean non_empty = gtk_clist_get_row_data(GTK_CLIST(personeditdlg.clist_attrib), 0) != NULL;
+	gboolean non_empty = gtk_cmclist_get_row_data(GTK_CMCLIST(personeditdlg.clist_attrib), 0) != NULL;
 	const gchar *atname;
 
 	if (personeditdlg.read_only || personeditdlg.ldap)
 		return;
 
-	atname = gtk_entry_get_text(GTK_ENTRY(GTK_BIN(personeditdlg.entry_atname)->child));
+	atname = gtk_entry_get_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN((personeditdlg.entry_atname)))));
 	if ( atname == NULL
 	||  strlen(atname) == 0) {
 		gtk_widget_set_sensitive(personeditdlg.attrib_add,FALSE);
@@ -1295,19 +1294,19 @@ static void addressbook_edit_person_page_attrib( gint pageNum, gchar *pageLbl )
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
 
-	clist = gtk_clist_new_with_titles( ATTRIB_N_COLS, titles );
+	clist = gtk_cmclist_new_with_titles( ATTRIB_N_COLS, titles );
 	gtk_container_add( GTK_CONTAINER(clist_swin), clist );
-	gtk_clist_set_selection_mode( GTK_CLIST(clist), GTK_SELECTION_BROWSE );
-	gtk_clist_set_compare_func( GTK_CLIST(clist), edit_person_attrib_compare_func );
-	gtk_clist_set_auto_sort( GTK_CLIST(clist), TRUE );
-	gtk_clist_set_column_width( GTK_CLIST(clist), ATTRIB_COL_NAME, ATTRIB_COL_WIDTH_NAME );
-	gtk_clist_set_column_width( GTK_CLIST(clist), ATTRIB_COL_VALUE, ATTRIB_COL_WIDTH_VALUE );
+	gtk_cmclist_set_selection_mode( GTK_CMCLIST(clist), GTK_SELECTION_BROWSE );
+	gtk_cmclist_set_compare_func( GTK_CMCLIST(clist), edit_person_attrib_compare_func );
+	gtk_cmclist_set_auto_sort( GTK_CMCLIST(clist), TRUE );
+	gtk_cmclist_set_column_width( GTK_CMCLIST(clist), ATTRIB_COL_NAME, ATTRIB_COL_WIDTH_NAME );
+	gtk_cmclist_set_column_width( GTK_CMCLIST(clist), ATTRIB_COL_VALUE, ATTRIB_COL_WIDTH_VALUE );
 
 	for( i = 0; i < ATTRIB_N_COLS; i++ )
-		GTK_WIDGET_UNSET_FLAGS(GTK_CLIST(clist)->column[i].button, GTK_CAN_FOCUS);
+		GTK_WIDGET_UNSET_FLAGS(GTK_CMCLIST(clist)->column[i].button, GTK_CAN_FOCUS);
 
 	/* Data entry area */
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 	table = gtk_table_new( 4, 2, FALSE);
 	gtk_container_add( GTK_CONTAINER(vboxl), clist_swin );
 	gtk_box_pack_start(GTK_BOX(vboxl), table, FALSE, FALSE, 0);
@@ -1315,7 +1314,7 @@ static void addressbook_edit_person_page_attrib( gint pageNum, gchar *pageLbl )
 	table = gtk_table_new( 2, 4, FALSE);
 	gtk_box_pack_start(GTK_BOX(vboxl), table, FALSE, FALSE, 0);
 	gtk_container_add( GTK_CONTAINER(vboxl), clist_swin );
-	gtk_clist_column_titles_hide(GTK_CLIST(clist));
+	gtk_cmclist_column_titles_hide(GTK_CMCLIST(clist));
 #endif
 	gtk_container_set_border_width( GTK_CONTAINER(table), 4 );
 	gtk_table_set_row_spacings(GTK_TABLE(table), 4);
@@ -1323,7 +1322,7 @@ static void addressbook_edit_person_page_attrib( gint pageNum, gchar *pageLbl )
 
 	/* First row */
 	top = 0;
-#ifndef MAEMO
+#ifndef GENERIC_UMPC
 	label = gtk_label_new(_("Name"));
 	gtk_table_attach(GTK_TABLE(table), label, 0, 1, top, (top + 1), GTK_FILL, 0, 0, 0);
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
@@ -1431,11 +1430,11 @@ static void addressbook_edit_person_create( GtkWidget *parent, gboolean *cancell
 * Return list of email items.
 */
 static GList *edit_person_build_email_list() {
-	GtkCList *clist = GTK_CLIST(personeditdlg.clist_email);
+	GtkCMCList *clist = GTK_CMCLIST(personeditdlg.clist_email);
 	GList *listEMail = NULL;
 	ItemEMail *email;
 	gint row = 0;
-	while( (email = gtk_clist_get_row_data( clist, row )) ) {
+	while( (email = gtk_cmclist_get_row_data( clist, row )) ) {
 		listEMail = g_list_append( listEMail, email );
 		row++;
 	}
@@ -1446,11 +1445,11 @@ static GList *edit_person_build_email_list() {
 * Return list of attributes.
 */
 static GList *edit_person_build_attrib_list() {
-	GtkCList *clist = GTK_CLIST(personeditdlg.clist_attrib);
+	GtkCMCList *clist = GTK_CMCLIST(personeditdlg.clist_attrib);
 	GList *listAttrib = NULL;
 	UserAttribute *attrib;
 	gint row = 0;
-	while( (attrib = gtk_clist_get_row_data( clist, row )) ) {
+	while( (attrib = gtk_cmclist_get_row_data( clist, row )) ) {
 		listAttrib = g_list_append( listAttrib, attrib );
 		row++;
 	}
@@ -1522,8 +1521,8 @@ static gboolean addressbook_edit_person_close( gboolean cancelled )
 	if( cancelled ) {
 		addritem_free_list_email( listEMail );
 		addritem_free_list_attribute( listAttrib );
-		gtk_clist_clear( GTK_CLIST(personeditdlg.clist_email) );
-		gtk_clist_clear( GTK_CLIST(personeditdlg.clist_attrib) );
+		gtk_cmclist_clear( GTK_CMCLIST(personeditdlg.clist_email) );
+		gtk_cmclist_clear( GTK_CMCLIST(personeditdlg.clist_attrib) );
 
 		if (!prefs_common.addressbook_use_editaddress_dialog)
 			gtk_widget_hide( personeditdlg.container );
@@ -1590,7 +1589,7 @@ static gboolean addressbook_edit_person_close( gboolean cancelled )
 			else 
 				name = g_strconcat( get_rc_dir(), G_DIR_SEPARATOR_S, ADDRBOOK_DIR, G_DIR_SEPARATOR_S, 
 						current_person->picture, ".png", NULL );
-			g_unlink(name);
+			claws_unlink(name);
 			g_free(name);
 		}
 		name = gtk_editable_get_chars( GTK_EDITABLE(personeditdlg.entry_first), 0, -1 );
@@ -1604,8 +1603,8 @@ static gboolean addressbook_edit_person_close( gboolean cancelled )
 		g_free( name );
 	}
 
-	gtk_clist_clear( GTK_CLIST(personeditdlg.clist_email) );
-	gtk_clist_clear( GTK_CLIST(personeditdlg.clist_attrib) );
+	gtk_cmclist_clear( GTK_CMCLIST(personeditdlg.clist_email) );
+	gtk_cmclist_clear( GTK_CMCLIST(personeditdlg.clist_attrib) );
 
 	if (!prefs_common.addressbook_use_editaddress_dialog)
 		gtk_widget_hide( personeditdlg.container );
@@ -1663,8 +1662,8 @@ ItemPerson *addressbook_edit_person( AddressBookFile *abf, ItemFolder *parent_fo
 	personeditdlg.rowIndEMail = -1;
 	personeditdlg.rowIndAttrib = -1;
 	edit_person_status_show( "" );
-	gtk_clist_clear( GTK_CLIST(personeditdlg.clist_email) );
-	gtk_clist_clear( GTK_CLIST(personeditdlg.clist_attrib) );
+	gtk_cmclist_clear( GTK_CMCLIST(personeditdlg.clist_email) );
+	gtk_cmclist_clear( GTK_CMCLIST(personeditdlg.clist_attrib) );
 	gtk_entry_set_text(GTK_ENTRY(personeditdlg.entry_name), "" );
 	gtk_entry_set_text(GTK_ENTRY(personeditdlg.entry_first), "" );
 	gtk_entry_set_text(GTK_ENTRY(personeditdlg.entry_last), "" );
@@ -1677,10 +1676,8 @@ ItemPerson *addressbook_edit_person( AddressBookFile *abf, ItemFolder *parent_fo
 		if( ADDRITEM_NAME(current_person) )
 			gtk_entry_set_text(GTK_ENTRY(personeditdlg.entry_name), ADDRITEM_NAME(person) );
 
-		menu_set_sensitive(personeditdlg.editaddr_popupfactory,
-				"/Set picture", !personeditdlg.ldap);
-		menu_set_sensitive(personeditdlg.editaddr_popupfactory,
-				"/Unset picture", !personeditdlg.ldap);
+		cm_menu_set_sensitive("EditAddressPopup/SetPicture", !personeditdlg.ldap);
+		cm_menu_set_sensitive("EditAddressPopup/UnsetPicture", !personeditdlg.ldap);
 		if( current_person->picture ) {	
 			filename = g_strconcat( get_rc_dir(), G_DIR_SEPARATOR_S, ADDRBOOK_DIR, G_DIR_SEPARATOR_S, 
 							current_person->picture, ".png", NULL );
@@ -1693,8 +1690,7 @@ ItemPerson *addressbook_edit_person( AddressBookFile *abf, ItemFolder *parent_fo
 					goto no_img;
 				}
 				personeditdlg.picture_set = TRUE;
-				menu_set_sensitive(personeditdlg.editaddr_popupfactory,
-						"/Unset picture", !personeditdlg.ldap && personeditdlg.picture_set);
+				cm_menu_set_sensitive("EditAddressPopup/UnsetPicture", !personeditdlg.ldap && personeditdlg.picture_set);
 			} else {
 				goto no_img;
 			}
@@ -1732,11 +1728,11 @@ no_img:
 		gtk_notebook_set_current_page( GTK_NOTEBOOK(personeditdlg.notebook), PAGE_BASIC );
 	}
 
-	gtk_clist_select_row( GTK_CLIST(personeditdlg.clist_email), 0, 0 );
-	gtk_clist_select_row( GTK_CLIST(personeditdlg.clist_attrib), 0, 0 );
+	gtk_cmclist_select_row( GTK_CMCLIST(personeditdlg.clist_email), 0, 0 );
+	gtk_cmclist_select_row( GTK_CMCLIST(personeditdlg.clist_attrib), 0, 0 );
 	edit_person_email_clear( NULL );
 	if (current_person)
-		edit_person_email_list_selected(GTK_CLIST(personeditdlg.clist_email), 0, 0, NULL, NULL);
+		edit_person_email_list_selected(GTK_CMCLIST(personeditdlg.clist_email), 0, 0, NULL, NULL);
 
 	edit_person_attrib_clear( NULL );
 
