@@ -40,6 +40,7 @@
 #include "prefs_common.h"
 #include "codeconv.h"
 #include "defs.h"
+#include "gtkutils.h"
 
 static void claws_spell_entry_init		(ClawsSpellEntry *entry);
 static void claws_spell_entry_editable_init	(GtkEditableClass *iface);
@@ -141,7 +142,6 @@ GtkWidget *claws_spell_entry_new(void)
 void claws_spell_entry_set_gtkaspell(ClawsSpellEntry *entry, GtkAspell *gtkaspell)
 {
 	cm_return_if_fail(CLAWS_IS_SPELL_ENTRY(entry));
-	cm_return_if_fail(gtkaspell != NULL);
 
 	entry->gtkaspell = gtkaspell;
 }
@@ -249,7 +249,7 @@ static gboolean word_misspelled(ClawsSpellEntry *entry, int start, int end)
 	gboolean ret;
 
 	word = get_word(entry, start, end);
-	if (word == NULL)
+	if (word == NULL || g_unichar_isdigit(word[0]))
 		return FALSE;
 		
 	ret = gtkaspell_misspelled_test(entry->gtkaspell, word);
@@ -258,6 +258,29 @@ static gboolean word_misspelled(ClawsSpellEntry *entry, int start, int end)
 	return ret;
 }
 
+static gboolean is_word_end (GtkEntry *entry, const int offset)
+{
+	gchar *p = gtk_editable_get_chars(GTK_EDITABLE(entry), offset, offset+1);
+	gunichar ch;
+	
+	ch = g_utf8_get_char(p);
+	g_free(p);
+	
+	if (ch == '\0')
+		return TRUE;
+
+	if (ch == '\'') {
+		p = gtk_editable_get_chars(GTK_EDITABLE(entry), offset+1, offset+2);
+		ch = g_utf8_get_char(p);
+		g_free(p);
+		
+		return (g_unichar_isspace(ch) || g_unichar_ispunct(ch)
+			|| g_unichar_isdigit(ch));
+	}
+	
+	return (g_unichar_isspace(ch) || g_unichar_ispunct(ch));
+}
+
 static void entry_strsplit_utf8(GtkEntry *entry, gchar ***set, gint **starts, gint **ends)
 {
 	PangoLayout   *layout;
@@ -287,7 +310,7 @@ static void entry_strsplit_utf8(GtkEntry *entry, gchar ***set, gint **starts, gi
 
 			/* Find the end of this string */
 			cend = i;
-			while (!(log_attrs[cend].is_word_end))
+			while (!is_word_end(entry, cend))
 				cend++;
 
 			/* Copy sub-string */
@@ -405,7 +428,7 @@ void claws_spell_entry_recheck_all(ClawsSpellEntry *entry)
 	layout = gtk_entry_get_layout(GTK_ENTRY(entry));
 	pango_layout_set_attributes(layout, entry->priv->attr_list);
 
-	if (GTK_WIDGET_REALIZED(GTK_WIDGET(entry))) {
+	if (gtkut_widget_get_realized(GTK_WIDGET(entry))) {
 		rect.x = 0; rect.y = 0;
 		rect.width  = GTK_WIDGET(entry)->allocation.width;
 		rect.height = GTK_WIDGET(entry)->allocation.height;
@@ -562,7 +585,7 @@ static void claws_spell_entry_populate_popup(ClawsSpellEntry *entry, GtkMenu *me
 {
 	GtkAspell *gtkaspell = entry->gtkaspell;
 	gint start, end;
-	gchar *word;
+	gchar *word, *text;
 	
 	if (gtkaspell == NULL)
         	return;
@@ -575,7 +598,12 @@ static void claws_spell_entry_populate_popup(ClawsSpellEntry *entry, GtkMenu *me
 	}
 
         gtkaspell->misspelled = word_misspelled(entry, start, end);
-        
+
+	text = gtk_editable_get_chars(GTK_EDITABLE(entry), 0, -1);
+	gtkaspell->start_pos  = g_utf8_pointer_to_offset(text, (text+start));
+	gtkaspell->end_pos    = g_utf8_pointer_to_offset(text, (text+end));
+	g_free(text);
+
         claws_spell_entry_context_set(entry);
         gtkaspell_make_context_menu(menu, gtkaspell);
 }
